@@ -62,7 +62,8 @@ pub fn upload(
                     let site_namespace = add_namespace(user, target, true)?;
 
                     let path = Path::new(&site_config.bucket);
-                    let (to_upload, asset_manifest) = sync(target, user, &site_namespace.id, path)?;
+                    let (to_upload, to_delete, asset_manifest) =
+                        sync(target, user, &site_namespace.id, path)?;
 
                     // First, upload all existing files in given directory
                     if verbose {
@@ -71,7 +72,16 @@ pub fn upload(
 
                     bulk::put(target, user, &site_namespace.id, to_upload, &None)?;
 
-                    authenticated_upload(&client, target, Some(asset_manifest))?
+                    let preview = authenticated_upload(&client, target, Some(asset_manifest))?;
+                    if !to_delete.is_empty() {
+                        if verbose {
+                            StdOut::info("Deleting stale files...");
+                        }
+
+                        bulk::delete(target, user, &site_namespace.id, to_delete, &None)?;
+                    }
+
+                    preview
                 } else {
                     authenticated_upload(&client, target, None)?
                 }
